bayespy.inference.vmp.nodes.gaussian_markov_chain.VaryingGaussianMarkovChainDistribution
========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. autoclass:: VaryingGaussianMarkovChainDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~VaryingGaussianMarkovChainDistribution.__init__
      ~VaryingGaussianMarkovChainDistribution.compute_cgf_from_parents
      ~VaryingGaussianMarkovChainDistribution.compute_fixed_moments_and_f
      ~VaryingGaussianMarkovChainDistribution.compute_gradient
      ~VaryingGaussianMarkovChainDistribution.compute_logpdf
      ~VaryingGaussianMarkovChainDistribution.compute_mask_to_parent
      ~VaryingGaussianMarkovChainDistribution.compute_message_to_parent
      ~VaryingGaussianMarkovChainDistribution.compute_moments_and_cgf
      ~VaryingGaussianMarkovChainDistribution.compute_phi_from_parents
      ~VaryingGaussianMarkovChainDistribution.plates_from_parent
      ~VaryingGaussianMarkovChainDistribution.plates_to_parent
      ~VaryingGaussianMarkovChainDistribution.random
   
   

   
   
   